from sqlalchemy import Column, Integer, String, Boolean
from solarbot_upload_image.controller.connection import Base


class Upload(Base):
    __tablename__ = "tb_upload"
    cd_upload = Column("cd_upload", Integer, primary_key=True, autoincrement=True)
    cd_tipo = Column("cd_tipo", Integer)
    cd_missao = Column("cd_missao", Integer)
    output = Column("output", String)
    flag_enviado = Column("flag_enviado", Boolean)
    vl_rgb = Column("vl_rgb", String)
    vl_depth = Column("vl_depth", String)

    def __init__(self, cd_tipo, cd_missao, output, flag_enviado, vl_rgb, vl_depth):
        self.cd_tipo = cd_tipo
        self.cd_missao = cd_missao
        self.output = output
        self.flag_enviado = flag_enviado
        self.vl_rgb = vl_rgb
        self.vl_depth = vl_depth



from solarbot_upload_image.controller.connection import Session
from solarbot_upload_image.model.upload import Upload


class UploadController:

    def __init__(self):
        pass

    @staticmethod
    def insert(upload):
        session = Session()
        session.add(upload)
        session.commit()
        session.close()

    @staticmethod
    def read():
        session = Session()
        result = session.query(Upload).all()
        session.close()

        return result

    @staticmethod
    def read_by_id(cd_upload):
        session = Session()
        result = session.query(Upload).filter(Upload.cd_upload == cd_upload).first()
        session.close()

        return result

    @staticmethod
    def read_by_type(cd_type):
        session = Session()
        result = session.query(Upload).filter(Upload.cd_tipo == cd_type).first()
        session.close()

        return result

    @staticmethod
    def read_by_send(flag):
        session = Session()
        result = session.query(Upload).filter(Upload.flag_enviado == flag).first()
        session.close()

        return result

    @staticmethod
    def update(update_upload):

        session = Session()
        upload = session.query(Upload).filter(Upload.cd_upload == update_upload.cd_upload).first()

        if upload is not None:
            upload.flag_enviado = update_upload.flag_enviado
            session.commit()
            session.refresh(upload)

        session.close()

    def delete(self, delete_upload):
        session = Session()
        upload = self.read_by_id(delete_upload.cd_upload)
        if upload is not None:
            session.delet(upload)
            session.commit()
        session.close()



from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker
from sqlalchemy import create_engine
import os 


def create_folder(folder):
    if not os.path.exists(folder):
        os.makedirs(folder)


PATH = "/home/madruga/image-upload/"
DB_NAME = "buffer.db"

create_folder(PATH)


engine = create_engine(f"sqlite:///{os.path.join(PATH, DB_NAME)}")
Session = sessionmaker(bind=engine)
Base = declarative_base()





from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 4 - Beta',
    'Intended Audience :: Education',
    'Programming Language :: Python :: 3',
    'Natural Language :: English'
]


setup(
    name='solarbot-upload-image',
    version='0.0.1',
    description='Upload images from robot',
    # long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.md').read(),
    author='Os Madrugas',
    author_email='gabrielmaulyfatec@gmail.com',
    url='',
    license='MIT',
    classifiers=classifiers,
    packages=find_packages(),
    install_requires=['sqlalchemy'],
    keywords='upload images'
)